@@ -53,7 +53,7 @@ class Scraper:
 
         if len(response) == 1:
             el = response[0]
-        elif pos is not None and len(response) > pos:
+        elif pos is not None and len(response) > 1:
             el = response[pos]
         else:
             el = response
